Struct FixedBytes
#[repr(transparent)]pub struct FixedBytes<const N: usize>(pub [u8; N]);Expand description
Newtype wrapper for Solidity ABI encoding/decoding [u8; N] for 1 <= N <= 32 as
fixed-size byte sequences.
Ref: https://docs.soliditylang.org/en/latest/types.html#fixed-size-byte-arrays
Tuple Fields
0: [u8; N]Implementations
impl<const N: usize> FixedBytes<N>
impl<const N: usize> FixedBytes<N>
pub fn from_ref(value: &[u8; N]) -> &FixedBytes<N>
pub fn from_ref(value: &[u8; N]) -> &FixedBytes<N>
Converts a reference to [u8; N] into a reference to FixedBytes<N> (without
copying).
Methods from Deref<Target = [u8; N]>
Sourcepub fn as_ascii(&self) -> Option<&[AsciiChar; N]>
🔬This is a nightly-only experimental API. (ascii_char)
pub fn as_ascii(&self) -> Option<&[AsciiChar; N]>
ascii_char)Converts this array of bytes into an array of ASCII characters,
or returns None if any of the characters is non-ASCII.
Examples
#![feature(ascii_char)]
const HEX_DIGITS: [std::ascii::Char; 16] =
*b"0123456789abcdef".as_ascii().unwrap();
assert_eq!(HEX_DIGITS[1].as_str(), "1");
assert_eq!(HEX_DIGITS[10].as_str(), "a");Sourcepub unsafe fn as_ascii_unchecked(&self) -> &[AsciiChar; N]
🔬This is a nightly-only experimental API. (ascii_char)
pub unsafe fn as_ascii_unchecked(&self) -> &[AsciiChar; N]
ascii_char)Converts this array of bytes into an array of ASCII characters, without checking whether they’re valid.
Safety
Every byte in the array must be in 0..=127, or else this is UB.
1.57.0 · Sourcepub fn as_slice(&self) -> &[T]
pub fn as_slice(&self) -> &[T]
Returns a slice containing the entire array. Equivalent to &s[..].
1.77.0 · Sourcepub fn each_ref(&self) -> [&T; N]
pub fn each_ref(&self) -> [&T; N]
Borrows each element and returns an array of references with the same
size as self.
Example
let floats = [3.1, 2.7, -1.0];
let float_refs: [&f64; 3] = floats.each_ref();
assert_eq!(float_refs, [&3.1, &2.7, &-1.0]);This method is particularly useful if combined with other methods, like
map. This way, you can avoid moving the original
array if its elements are not Copy.
let strings = ["Ferris".to_string(), "♥".to_string(), "Rust".to_string()];
let is_ascii = strings.each_ref().map(|s| s.is_ascii());
assert_eq!(is_ascii, [true, false, true]);
// We can still access the original array: it has not been moved.
assert_eq!(strings.len(), 3);Sourcepub fn split_array_ref<const M: usize>(&self) -> (&[T; M], &[T])
🔬This is a nightly-only experimental API. (split_array)
pub fn split_array_ref<const M: usize>(&self) -> (&[T; M], &[T])
split_array)Divides one array reference into two at an index.
The first will contain all indices from [0, M) (excluding
the index M itself) and the second will contain all
indices from [M, N) (excluding the index N itself).
Panics
Panics if M > N.
Examples
#![feature(split_array)]
let v = [1, 2, 3, 4, 5, 6];
{
let (left, right) = v.split_array_ref::<0>();
assert_eq!(left, &[]);
assert_eq!(right, &[1, 2, 3, 4, 5, 6]);
}
{
let (left, right) = v.split_array_ref::<2>();
assert_eq!(left, &[1, 2]);
assert_eq!(right, &[3, 4, 5, 6]);
}
{
let (left, right) = v.split_array_ref::<6>();
assert_eq!(left, &[1, 2, 3, 4, 5, 6]);
assert_eq!(right, &[]);
}Sourcepub fn rsplit_array_ref<const M: usize>(&self) -> (&[T], &[T; M])
🔬This is a nightly-only experimental API. (split_array)
pub fn rsplit_array_ref<const M: usize>(&self) -> (&[T], &[T; M])
split_array)Divides one array reference into two at an index from the end.
The first will contain all indices from [0, N - M) (excluding
the index N - M itself) and the second will contain all
indices from [N - M, N) (excluding the index N itself).
Panics
Panics if M > N.
Examples
#![feature(split_array)]
let v = [1, 2, 3, 4, 5, 6];
{
let (left, right) = v.rsplit_array_ref::<0>();
assert_eq!(left, &[1, 2, 3, 4, 5, 6]);
assert_eq!(right, &[]);
}
{
let (left, right) = v.rsplit_array_ref::<2>();
assert_eq!(left, &[1, 2, 3, 4]);
assert_eq!(right, &[5, 6]);
}
{
let (left, right) = v.rsplit_array_ref::<6>();
assert_eq!(left, &[]);
assert_eq!(right, &[1, 2, 3, 4, 5, 6]);
}Trait Implementations
impl<const N: usize> Clone for FixedBytes<N>
impl<const N: usize> Clone for FixedBytes<N>
fn clone(&self) -> FixedBytes<N>
fn clone(&self) -> FixedBytes<N>
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreimpl<const N: usize> Debug for FixedBytes<N>
impl<const N: usize> Debug for FixedBytes<N>
impl<const N: usize> Decode for FixedBytes<N>
impl<const N: usize> Decode for FixedBytes<N>
fn decode<__CodecInputEdqy>(
__codec_input_edqy: &mut __CodecInputEdqy,
) -> Result<FixedBytes<N>, Error>where
__CodecInputEdqy: Input,
fn decode<__CodecInputEdqy>(
__codec_input_edqy: &mut __CodecInputEdqy,
) -> Result<FixedBytes<N>, Error>where
__CodecInputEdqy: Input,
fn decode_into<__CodecInputEdqy>(
__codec_input_edqy: &mut __CodecInputEdqy,
dst_: &mut MaybeUninit<FixedBytes<N>>,
) -> Result<DecodeFinished, Error>where
__CodecInputEdqy: Input,
fn decode_into<__CodecInputEdqy>(
__codec_input_edqy: &mut __CodecInputEdqy,
dst_: &mut MaybeUninit<FixedBytes<N>>,
) -> Result<DecodeFinished, Error>where
__CodecInputEdqy: Input,
fn skip<I>(input: &mut I) -> Result<(), Error>where
I: Input,
fn skip<I>(input: &mut I) -> Result<(), Error>where
I: Input,
fn encoded_fixed_size() -> Option<usize>
fn encoded_fixed_size() -> Option<usize>
impl<const N: usize> Deref for FixedBytes<N>
impl<const N: usize> Deref for FixedBytes<N>
impl<const N: usize> Encode for FixedBytes<N>
impl<const N: usize> Encode for FixedBytes<N>
fn encode_to<__CodecOutputEdqy>(
&self,
__codec_dest_edqy: &mut __CodecOutputEdqy,
)where
__CodecOutputEdqy: Output + ?Sized,
fn encode_to<__CodecOutputEdqy>(
&self,
__codec_dest_edqy: &mut __CodecOutputEdqy,
)where
__CodecOutputEdqy: Output + ?Sized,
fn using_encoded<__CodecOutputReturn, __CodecUsingEncodedCallback>(
&self,
f: __CodecUsingEncodedCallback,
) -> __CodecOutputReturn
fn using_encoded<__CodecOutputReturn, __CodecUsingEncodedCallback>( &self, f: __CodecUsingEncodedCallback, ) -> __CodecOutputReturn
fn encoded_size(&self) -> usize
fn encoded_size(&self) -> usize
impl<const N: usize> From<[u8; N]> for FixedBytes<N>
impl<const N: usize> From<[u8; N]> for FixedBytes<N>
fn from(value: [u8; N]) -> FixedBytes<N>
fn from(value: [u8; N]) -> FixedBytes<N>
impl<const N: usize> From<FixedBytes<N>> for [u8; N]
impl<const N: usize> From<FixedBytes<N>> for [u8; N]
fn from(value: FixedBytes<N>) -> [u8; N]
fn from(value: FixedBytes<N>) -> [u8; N]
impl From<u8> for FixedBytes<1>
impl From<u8> for FixedBytes<1>
fn from(value: u8) -> FixedBytes<1>
fn from(value: u8) -> FixedBytes<1>
impl<const N: usize> PartialEq for FixedBytes<N>
impl<const N: usize> PartialEq for FixedBytes<N>
impl<const N: usize> SolDecode for FixedBytes<N>where
ByteCount<N>: SupportedFixedBytes,
impl<const N: usize> SolDecode for FixedBytes<N>where
ByteCount<N>: SupportedFixedBytes,
type SolType = FixedBytes<N>
type SolType = FixedBytes<N>
fn from_sol_type(
value: <FixedBytes<N> as SolDecode>::SolType,
) -> Result<FixedBytes<N>, Error>
fn from_sol_type( value: <FixedBytes<N> as SolDecode>::SolType, ) -> Result<FixedBytes<N>, Error>
Self from Self::SolType.impl<'a, const N: usize> SolEncode<'a> for FixedBytes<N>where
ByteCount<N>: SupportedFixedBytes,
impl<'a, const N: usize> SolEncode<'a> for FixedBytes<N>where
ByteCount<N>: SupportedFixedBytes,
type SolType = &'a FixedBytes<N>
type SolType = &'a FixedBytes<N>
fn to_sol_type(&'a self) -> <FixedBytes<N> as SolEncode<'a>>::SolType
fn to_sol_type(&'a self) -> <FixedBytes<N> as SolEncode<'a>>::SolType
Self to Self::SolType via either a borrow (if possible), or
a possibly expensive conversion otherwise.const SOL_NAME: &'static str = <<Self::SolType as SolTypeEncode>::AlloyType as AlloySolType>::SOL_NAME
const SOL_NAME: &'static str = <<Self::SolType as SolTypeEncode>::AlloyType as AlloySolType>::SOL_NAME
impl<const N: usize> SolTopicEncode for FixedBytes<N>where
ByteCount<N>: SupportedFixedBytes,
impl<const N: usize> SolTopicEncode for FixedBytes<N>where
ByteCount<N>: SupportedFixedBytes,
fn encode_topic<H>(&self, _: H) -> [u8; 32]
fn encode_topic<H>(&self, _: H) -> [u8; 32]
fn topic_preimage(&self, buffer: &mut Vec<u8>)
fn topic_preimage(&self, buffer: &mut Vec<u8>)
fn default_topic_preimage(buffer: &mut Vec<u8>)
fn default_topic_preimage(buffer: &mut Vec<u8>)
Self::topic_preimage equivalent for the default value representation of this
type.fn topic_preimage_size(&self) -> usize
fn topic_preimage_size(&self) -> usize
Self::topic_preimage encoding of this type.fn default_topic_preimage_size() -> usize
fn default_topic_preimage_size() -> usize
Self::topic_preimage_size equivalent for the default value representation of
this type.impl<const N: usize> SolTypeDecode for FixedBytes<N>where
ByteCount<N>: SupportedFixedBytes,
impl<const N: usize> SolTypeDecode for FixedBytes<N>where
ByteCount<N>: SupportedFixedBytes,
fn detokenize(
token: <<FixedBytes<N> as SolTypeDecode>::AlloyType as SolType>::Token<'_>,
) -> Result<FixedBytes<N>, Error>
fn detokenize( token: <<FixedBytes<N> as SolTypeDecode>::AlloyType as SolType>::Token<'_>, ) -> Result<FixedBytes<N>, Error>
impl<const N: usize> SolTypeEncode for FixedBytes<N>where
ByteCount<N>: SupportedFixedBytes,
impl<const N: usize> SolTypeEncode for FixedBytes<N>where
ByteCount<N>: SupportedFixedBytes,
const DEFAULT_VALUE: <FixedBytes<N> as SolTokenType>::DefaultType = {transmute(0x0000000000000001): <ink_primitives::sol::FixedBytes<N> as ink_primitives::sol::types::SolTokenType>::DefaultType}
const DEFAULT_VALUE: <FixedBytes<N> as SolTokenType>::DefaultType = {transmute(0x0000000000000001): <ink_primitives::sol::FixedBytes<N> as ink_primitives::sol::types::SolTokenType>::DefaultType}
fn tokenize(&self) -> <FixedBytes<N> as SolTokenType>::TokenType<'_>
fn tokenize(&self) -> <FixedBytes<N> as SolTokenType>::TokenType<'_>
Self::AlloyType token.impl<const N: usize> TypeInfo for FixedBytes<N>
impl<const N: usize> TypeInfo for FixedBytes<N>
impl<const N: usize> Copy for FixedBytes<N>
impl<const N: usize> EncodeLike for FixedBytes<N>
impl<const N: usize> Eq for FixedBytes<N>
impl<const N: usize> StructuralPartialEq for FixedBytes<N>